# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that creates triggers for play
the radio.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

from gobject import GObject, SIGNAL_RUN_LAST, TYPE_NONE

class Trigger(GObject):
	"""
	This trigger initializes the play button and the triggers to
	play radio.
	"""

	__gsignals__ = {
		"destroy": (SIGNAL_RUN_LAST, TYPE_NONE, ()),
	}

	def __init__(self, player):
		"""
		Initialize the trigger.

		@param self: Reference to the Trigger instance.
		@type self: An Trigger object.

		@param player: Reference to the player.
		@type player: An Player object.
		"""
		GObject.__init__(self)
		self.__init_attributes(player)
		self.__create_triggers()
		self.__signal_id_1 = self.__play_trigger.connect("activate", self.__play_trigger_cb)
		self.__signal_id_2 = self.__toggle_trigger.connect("activate", self.__play_trigger_cb)
		self.__signal_id_3 = self.connect("destroy", self.__destroy_cb)

	def __init_attributes(self, player):
		"""
		Initialize the trigger's attributes.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.

		@param player: Reference to the player.
		@type player: An Player object.
		"""
		self.__player = player
		from Manager import Manager
		self.__manager = Manager(self, player)
		self.__play_trigger = None
		self.__toggle_trigger = None
		self.__signal_id_1 = self.__signal_id_2 = None
		return

	def __create_triggers(self):
		"""
		Create the trigger.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.
		"""
		from Striim.Trigger import Trigger

		# Triggers to play radio station.
		self.__play_trigger = Trigger("play", "p")
		self.__toggle_trigger = Trigger("toggle", "Return")
		self.__player.add_triggers([self.__play_trigger, self.__toggle_trigger])
		return

	def __play_trigger_cb(self, trigger):
		"""
		Handles callback when the "activate" signal is emitted.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.

		@param trigger: An object that shows striim's window.
		@type trigger: A Trigger object.
		"""
		self.__manager.play()
		return

	def __destroy_cb(self, trigger):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the Trigger instance.
		@type self: An Trigger object.

		@param trigger: Reference to the Trigger instance.
		@type trigger: An Trigger object.
		"""
		triggers = [self.__play_trigger, self.__toggle_trigger]
		self.__player.remove_triggers(triggers)
		from Striim.utils import disconnect_signal, delete_attributes
		disconnect_signal(self.__signal_id_1, self.__play_trigger)
		disconnect_signal(self.__signal_id_2, self.__toggle_trigger)
		disconnect_signal(self.__signal_id_3, self)
		delete_attributes(self)
		del self
		self = None
		return

	def destroy(self):
		"""
		Destroy this object.

		@param self: Reference to the Trigger instance.
		@type self: A Trigger object.
		"""
		self.emit("destroy")
		return
