# -*- coding: utf-8 -*-
# Copyright © 2007 Lateef Alabi-Oki
#
# This file is part of striim.
#
# striim is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
# USA

"""
This module documents a class that defines the behavior of the Add
button on the stations window.

@author: Lateef Alabi-Oki
@organization: The Scribes Project
@copyright: Copyright © 2007 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

class AddButton(object):
	"""
	This class defines the behavior of the "Add" button.
	"""

	def __init__(self, manager, player):
		"""
		Initialize object.

		@param self: Reference to the AddButton instance.
		@type self: An AddButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__init_attributes(manager, player)
		self.__signal_id_1 = manager.connect("destroy", self.__destroy_cb)
		self.__signal_id_2 = self.__button.connect("clicked", self.__clicked_cb)

	def __init_attributes(self, manager, player):
		"""
		Initialize data attributes.

		@param self: Reference to the AddButton instance.
		@type self: An AddButton object.

		@param manager: Reference to the Manager instance.
		@type manager: A Manager object.

		@param player: Reference to the Player instance.
		@type player: A Player object.
		"""
		self.__manager = manager
		self.__player = player
		self.__button = manager.glade.get_widget("AddButton")
		self.__dialog = None
		self.__signal_id_1 = self.__signal_id_2 = None
		return

	def __destroy_cb(self, *args):
		"""
		Handles callback when the "destroy" signal is emitted.

		@param self: Reference to the AddButton instance.
		@type self: A AddButton object.
		"""
		from Striim.utils import delete_attributes, disconnect_signal
		disconnect_signal(self.__signal_id_1, self.__manager)
		disconnect_signal(self.__signal_id_2, self.__button)
		self.__button.destroy()
		delete_attributes(self)
		del self
		self = None
		return

	def __clicked_cb(self, *args):
		"""
		Handles callback when the "clicked" signal is emitted.

		@param self: Reference to the AddButton instance.
		@type self: An AddButton object.
		"""
		try:
			self.__dialog.show_dialog()
		except AttributeError:
			from AddDialog import AddDialog
			self.__dialog = AddDialog(self.__manager, self.__player)
			self.__dialog.show_dialog()
		return False
